setuptools_scm_git_archive: setuptools_scm plugin for git archives
==================================================================

Description
-----------

setuptools_scm plugin for git archives

License
-------

MIT

Upstream Contact
----------------

https://pypi.org/project/setuptools-scm-git-archive/

